@@ -6,7 +6,7 @@ Net::ISC::DHCPd - Interacts with ISC DHCPd
 
 =head1 VERSION
 
-0.1704
+0.1707
 
 =head1 SYNOPSIS
 
@@ -16,7 +16,7 @@ Net::ISC::DHCPd - Interacts with ISC DHCPd
                     omapi => { key => "some key" },
                 );
 
-    $self->test('config') or die $self->errstr;
+    $dhcpd->config->parse;
 
 See the tests bundled to this distribution for more examples.
 
@@ -35,15 +35,15 @@ L<the man pages|http://www.google.com/search?q=man+dhcpd>.
 
 =cut
 
-use Class::Load;
-use Moose;
+use Class::Load 0.20;
+use Moose 0.90;
 use Moose::Util::TypeConstraints;
-use MooseX::Types::Path::Class qw(File);
+use MooseX::Types::Path::Class 0.05 qw(File);
 use Net::ISC::DHCPd::Types ':all';
-use File::Temp;
+use File::Temp 0.20;
 use v5.12.5;
 
-our $VERSION = eval '0.1704';
+our $VERSION = eval '0.1707';
 
 =head1 ATTRIBUTES
 
@@ -114,7 +114,7 @@ has binary => (
 
 =head2 errstr
 
-Holds the last know error as a plain string.
+Holds the last know error as a plain string.  This only applies to OMAPI.
 
 =cut
 
@@ -126,6 +126,23 @@ has errstr => (
 
 =head1 METHODS
 
+=head2 parse
+
+ $config->parse;
+
+This parses the config file or the leases file.
+
+=cut
+
+=head2 generate
+
+ print $config->generate;
+
+This generates a copy of the config file in plaintext.
+
+=cut
+
+
 =head2 test
 
  $bool = $self->test("config");
@@ -208,11 +225,27 @@ sub _build_child_obj {
     return "Net::ISC::DHCPd::$type"->new(@_);
 }
 
+=head1 SEE ALSO
+
+=over 8
+
+=item Net::DHCP::Info
+
+C<Net::DHCP::Info> an older dhcpd.leases and dhcpd.conf parser, also written
+by Jan Henning Thorsen.  It has many limitations that these modules address.
+
+=item kea.isc.org
+
+C<kea.isc.org> a replacement DHCP server from ISC that is high-performance and
+supports an API and on-line configuration directly.
+
+=back
+
 =head1 BUGS
 
 Please report any bugs or feature requests to
 C<bug-net-isc-dhcpd at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-ISC-DHCPd>.
+L<https://github.com/jhthorsen/net-isc-dhcpd/issues>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
@@ -227,6 +260,10 @@ under the same terms as Perl itself.
 
 Jan Henning Thorsen, C<< <jhthorsen at cpan.org> >>
 
+=head1 MAINTAINER
+
+Robert Drake, C<< <rdrake at cpan.org> >>
+
 =head1 CONTRIBUTORS
 
 Nito Martinez
@@ -237,6 +274,8 @@ Patrick
 
 napetrov
 
+zoffixznet
+
 =cut
 __PACKAGE__->meta->make_immutable;
 1;
